#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-07-06 14:02:20.222384

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.hybrid_shape_interfaces.line import Line


class HybridShapeLineExplicit(Line):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     MecModInterfaces.HybridShape
                |                         CATGSMIDLItf.Line
                |                             HybridShapeLineExplicit
                | 
                | Represents the hybrid shape line explicit feature object.
                | Role: Declare hybrid shape line explicit feature object.
                | 
                | See also:
                |     HybridShapeFactory.AddNewLineDatum 

    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.hybrid_shape_line_explicit = com_object

    def __repr__(self):
        return f'HybridShapeLineExplicit(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.any_object import AnyObject


class ToleranceZone(AnyObject):

    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     ToleranceZone
                | 
                | Interface for accessing tolerance zone informations of a TPS.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.tolerance_zone = com_object

    @property
    def form(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Form() As CATBSTR
                | 
                |     Retrieves tolerance zone form.

        :return: str
        :rtype: str
        """

        return self.tolerance_zone.Form

    @form.setter
    def form(self, value: str):
        """
        :param str value:
        """

        self.tolerance_zone.Form = value

    @property
    def value(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Value() As double
                | 
                |     Retrieves tolerance zone value (in millimeters).

        :return: float
        :rtype: float
        """

        return self.tolerance_zone.Value

    @value.setter
    def value(self, value: float):
        """
        :param float value:
        """

        self.tolerance_zone.Value = value

    def __repr__(self):
        return f'ToleranceZone(name="{ self.name }")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.part_interfaces.revolution import Revolution


class Shaft(Revolution):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     MecModInterfaces.Shape
                |                         PartInterfaces.SketchBasedShape
                |                             PartInterfaces.Revolution
                |                                 Shaft
                | 
                | Represents the shaft shape.
                | A shaft is made up of a sketch, used as the shaft profile, and containing an
                | axis, used as the revolution axis, and two limiting angles around this axis.
                | This is a "positive" shape: it adds material to the body it belongs
                | to.

    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.shaft = com_object

    def __repr__(self):
        return f'Shaft(name="{self.name}")'
